/* 
 Programma di controllo per un dolly motorizzato
 Versione 1.1 17/03/2012
 Hardware utilizzato:
 - Arduino 2009 + shield motor adafruit + alcuni tasti e alcuni led
 - Configurazione degli ingressi e delle uscite:
 - 0 Non usato perchè utilizzato da arduino per comunicare via USB
 - 1 Non usato perchè utilizzato da arduino per comunicare via USB
 - 2 Out per comandare la macchina fotografica (scatto vero e proprio)
 - 3 Non usato perchè utilizzato dallo shield per comandare il motore passo passo
 - 4 Non usato perchè utilizzato dallo shield per comandare il motore passo passo
 - 5 In per incrementare il valore inserito di una decina
 - 6 In per incrementare il valore inserito di una unità
 - 7 Non usato perchè utilizzato dallo shield per comandare il motore passo passo 
 - 8 Non usato perchè utilizzato dallo shield per comandare il motore passo passo
 - 9 In per visualizzare tramite led il valore inserito
 - 10 In per cancellare il valore inserito (ed eventualmente fermare il ciclo)
 - 11 Non usato perchè utilizzato dallo shield per comandare il motore passo passo 
 - 12 Non usato perchè utilizzato dallo shield per comandare il motore passo passo 
 - 13 Led di segnalazione funzionamento motore
 - I pin da 14 a 19 sono i 6 ingressi analogici (0-5) (0=14; 1=15; 2=16; 3=17; 4=18; 5=19)
 - 14 Non usato (libero)
 - 15 In per Stop DX
 - 16 In per Stop SX
 - 17 Non usato (libero)
 - 18 Non usato (libero)
 - 19 In potenziometro per impostare la lunghezza del passo
 */

#include <AFMotor.h> // necessario per comandare i motori tramite adafruit

//imposto gli ingressi
const int Scatto = 2;               // Uscita da collegare tramite optoisolatore allo scatto della macchina fotografica
const int BottoneDecine = 5;        // Il bottone per incrementare le decine è al pin 5
const int BottoneUnita = 6;         // Il bottone per incrementare le unità è al pin 6
const int BottoneVisualizza = 9;    // Il bottone per visualizzare il valore è al pin 9
const int BottoneCancella = 10;     // Il bottone per fare clear è al pin 10
const int LedPin =  13;             // Il led 13 viene utilizzato per visualizzare il valore e funzionamento motore
const int StopSX = 15;              // il bottone StopSX di sicurezza è al pin 1 analogico = 15 digitale
const int StopDX = 16;              // il bottone StopDX di sicurezza è al pin 2 analogico = 16 digitale
const int PotPassi = A5;            // Potenziometro per la lunghezza del passo


//imposto i valori di alcuni parametri fissi
const int PassiMotore = 48;           // Il numero di passi del motore per compiere un giro dello stesso (48) 
const int lunghezza=2666;             // Sono necessari 2666 passi per fare tutto il binario (1 metro)
int LimitePassi=20;             // limite n° di foto da effettuare

//n° di passi che il motore deve compiere a seconda del valore impostato con il potenziometro
const int passo1=1;
const int passo2=2;
const int passo3=3;
const int passo4=4;
const int passo5=5;
const int passo6=6;
const int passo7=8;
const int passo8=12;
const int passo9=16;
const int passo10=32;
const int passo11=64;



//inizializzazione del motore e di alcune variabili
AF_Stepper motor(PassiMotore, 1);


// Variabili utilizzate 
int sensorValue = 0;                     // variabile per memorizzare il valore letto dal potenziometro
int ValoreUnita = 1;                     // per conteggio delle volte che viene premuto il tasto unita
int ValoreDecine = 0;                    // per conteggio delle volte che viene premuto il tasto decine
unsigned long ValoreMemorizzato = 0;     // variabile che conterrà il valore inserito  
int passo=passo9;                        // per default 16 passi
long RitardoFiltraggio = 50;             // Ritardo per filtraggio di falsi contatti. Se è il caso aumentarlo
int FCSX = 0;                            // Variabile che contiene lo stato del fine corsa SX
int FCDX = 0;                            // Variabile che contiene lo stato del fine corsa DX
int Passi = 0;                           // variabile che contiene il numero di passi effettuati
int Motore = 0;                          // variabile per accendere e spegnere il motore
int SensoRotazioneMotore = 1;            // variabile che contiene il senso di rotazione del motore

//variabili usate per evitare eventuali falsi contatti della "tastiera"
//in alcuni casi vengono utilizzate variabili long perchè il valore 
//memorizzato potrebbe superare la capacità degli int 
//poichè si tratta di millisecondi
int StatoBottoneUnita;                   // Contiene lo stato del bottone unita
int UltimoStatoBottoneUnita = LOW;       // variabile che contiene l'ultima lettura dello stato delle unita
long TempoBottoneUnita = 0;              // variabile che contiene ...

int StatoBottoneDecine;                  // Contiene lo stato del bottone decine
int UltimoStatoBottoneDecine = LOW;      // variabile che contiene l'ultima lettura dello stato delle decine
long TempoBottoneDecine = 0;             // variabile che contiene il tempo per i falsi contatti

int StatoBottoneCancella;                // Contiene lo stato del bottone Cancella
int UltimoStatoBottoneCancella = LOW;    // variabile che contiene l'ultima lettura dello stato di Cancella
long TempoBottoneCancella = 0;           // variabile che contiene il tempo per i falsi contatti

int StatoBottoneVisualizza;              // Contiene lo stato del bottone Visualizza
int UltimoStatoBottoneVisualizza = LOW;  // variabile che contiene l'ultima lettura dello stato di Visualizza
long TempoBottoneVisualizza = 0;         // variabile che contiene il tempo per i falsi contatti

int StatoStopDX;                    // Contiene lo stato del StopDX
int UltimoStatoStopDX = LOW;        // variabile che contiene l'ultima lettura dello stato di StopDX
long TempoStopDX = 0;               // variabile che contiene il tempo per i falsi contatti
  
int StatoStopSX;                    // Contiene lo stato del StopSX
int UltimoStatoStopSX = LOW;        // variabile che contiene l'ultima lettura dello stato di StopSX
long TempoStopSX = 0;               // variabile che contiene il tempo per i falsi contatti



//funzione VISUALIZZA
//funzione VISUALIZZA
//funzione VISUALIZZA
//funzione VISUALIZZA
//funzione VISUALIZZA
//funzione VISUALIZZA
// Questa funzione serve per visualizzare tramite l'accensione del led al pin 13 (LedPin) un valore
// (si accende tot=valore volte)
void Visualizza (int valore)
{
   for (int ciclo=0;ciclo<valore;ciclo++)
   {
     digitalWrite(LedPin, LOW);    // set the LED off
     delay(400);              // wait for a second
     digitalWrite(LedPin, HIGH);   // set the LED on
     delay(400);              // wait for a second
   }
  digitalWrite(LedPin, LOW);    // set the LED off
}       

//funzione StampaSituazione
//funzione StampaSituazione
//funzione StampaSituazione
//funzione StampaSituazione
//funzione StampaSituazione
//funzione StampaSituazione
//funzione StampaSituazione
// Questa funzione serve per trasmettere via seriale dei dati che possono essere visualizzati.
// E' utile per effettuare un debug ed un controllo che tutto funzioni correttamente.
// Se arduino e collegato al PC (tramite l'USB) se si lancia il tools Serial Monitor si vedono i messaggi 
// trasmessi da questa funzione
void StampaSituazione(String Messaggio)
{
  String s;
  s= "" ;
  s = s  + " Passi= ";
  s = s  + Passi;
  s = s  + " - FCSX= ";
  s = s  + FCSX;
  s = s   + " - FCDX= ";
  s = s  + FCDX;
  s = s   + " - Motore= ";
  s = s   + Motore;
  s = s   + " - Senso di rotazione=";
  s = s   + SensoRotazioneMotore;
  s = s   + " -MSG=";
  s = s   + Messaggio;
  Serial.println(s);
}


//funzione Pressione
//funzione Pressione
//funzione Pressione
//funzione Pressione
//funzione Pressione
//funzione Pressione
// Questa funzione serve per accendere e spegnere il led per segnalare una pressione di un bottone
void Pressione (String Messaggio)
{
    StampaSituazione(Messaggio); //trasmetto via seriale che è stato premuto il bottone
    digitalWrite(LedPin, HIGH);   // set the LED on
    delay(900);              // wait for a second
    digitalWrite(LedPin, LOW);    // set the LED off
}       

//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
//Funzione SETUP
// Questa funzione è necessaria ad arduino per inizializzare il proprio Hardware. Vengono impostati
// gli ingressi e le uscite, la scheda seriale, il motore e la sua velocità
void setup() {
  Serial.begin(9600);                           // set up Serial library at 9600 bps
  pinMode(BottoneCancella, INPUT);              // imposto gli ingressi per la tastiera 
  pinMode(BottoneVisualizza, INPUT);
  pinMode(BottoneUnita, INPUT);
  pinMode(BottoneDecine, INPUT);
  pinMode(StopDX, INPUT);
  pinMode(StopSX, INPUT);
  pinMode(LedPin, OUTPUT);                     // imposto l'uscita per il led di segnalazione
  pinMode(Scatto, OUTPUT);                     // imposto l'uscita per il led di segnalazione
  motor.setSpeed(180);  // 180 rpm  
  motor.release();
}


//Funzione loop
//Funzione loop
//Funzione loop
//Funzione loop
//Funzione loop
// Questa funzione viene eseguita in modo continuo da arduino. E' il ciclo del programma da eseguire

void loop() {
  String s1;                           // variabile per contenere una eventuale stringa 
  FCSX = 0;                            // Azzero lo stato del fine corsa SX
  FCDX = 0;                            // Azzero lo stato del fine corsa DX
  int velmotore=180;                   // variabile per contenere la velocità del motore in modalità semiautomatica
  int interrotto = 0;                  // variabile per verificare se è intervenuta una emergenza
  // inizio la lettura dei vari ingressi (bottoni, fine corsa, potenziometro)
  

  //lettura dello stato del bottone Cancella
  //lettura dello stato del bottone Cancella
  //lettura dello stato del bottone Cancella
  //lettura dello stato del bottone Cancella
  int LetturaBottoneCancella = digitalRead(BottoneCancella);
  if (LetturaBottoneCancella != UltimoStatoBottoneCancella) //se è cambiato 
  {
      TempoBottoneCancella = millis(); // Memorizzo quando è stato premuto il bottone per la prima volta
  } 
  if ((millis() - TempoBottoneCancella) > RitardoFiltraggio) // se il tempo di filtraggio è maggiore del tempo limite allora cambia lo stato
  {
      StatoBottoneCancella = LetturaBottoneCancella;
      if (LetturaBottoneCancella==HIGH)
      {
          //ho la conferma che è stato premuto il tasto cancella
          StampaSituazione("Bottone Cancella"); // trasmetto il messaggio via seriale per controllo
          ValoreUnita=0; //azzero le unità
          ValoreDecine=0; // azzero le decine
          Motore=0; // spengo il motore
          // Per visualizzare che è stato premuto il bottone cancella, accendo e spengo il led per 10 volte in modo veloce
          for (int ciclo=0;ciclo<10;ciclo++)
          {
              digitalWrite(LedPin, HIGH);   // Accendo il led per segnalare la pressione del bottone
              delay(100);                   // wait for a second
              digitalWrite(LedPin, LOW);    // set the LED off
              delay(100);              // wait for a second
          }
      }  
  }
  UltimoStatoBottoneCancella = LetturaBottoneCancella;//memorizza lo stato per confrontarlo al prossimo ciclo


  //lettura dello stato del bottone Visualizza
  //lettura dello stato del bottone Visualizza
  //lettura dello stato del bottone Visualizza
  //lettura dello stato del bottone Visualizza
  int LetturaBottoneVisualizza = digitalRead(BottoneVisualizza);
  if (LetturaBottoneVisualizza != UltimoStatoBottoneVisualizza)   //se è cambiato
  {
      TempoBottoneVisualizza = millis(); // Memorizzo quando è stato premuto il bottone per la prima volta
  } 
  if ((millis() - TempoBottoneVisualizza) > RitardoFiltraggio) // se il tempo di filtraggio è maggiore del tempo limite allora cambia lo stato
  {
      StatoBottoneVisualizza = LetturaBottoneVisualizza;
      if (LetturaBottoneVisualizza==HIGH)
      {
          //ho la conferma che è stato premuto il tasto visualizza
          StampaSituazione("Bottone Visualizza");
          delay(500);              // faccio una pausa di mezzo secondo
          Visualizza(ValoreDecine);// visualizzo tramite il led il valore delle decine
          delay(1000);              // faccio una pausa di mezzo secondo
          Visualizza(ValoreUnita); // visualizzo tramite il led il valore delle unità
          //trasmetto via seriale alcuni valori impostati
          sensorValue = analogRead(PotPassi);    
          s1= "" ;
          s1 = s1  + "Intervallo= ";
          s1 = s1  + ValoreMemorizzato;
          s1 = s1  + "  Potenziometro= ";
          s1 = s1  + sensorValue;
          s1 = s1  + " Passo= ";
          s1 = s1  + passo;
          Serial.println(s1);
      }  
  }
  UltimoStatoBottoneVisualizza = LetturaBottoneVisualizza;//memorizza lo stato per confrontarlo al prossimo ciclo
  
  
  //lettura dello stato del bottone unita
  //lettura dello stato del bottone unita
  //lettura dello stato del bottone unita
  //lettura dello stato del bottone unita
  //lettura dello stato del bottone unita
  int LetturaBottoneUnita = digitalRead(BottoneUnita);
  if (LetturaBottoneUnita != UltimoStatoBottoneUnita) //se è cambiato
  {
      TempoBottoneUnita = millis();// Memorizzo quando è stato premuto il bottone per la prima volta
  } 
  if ((millis() - TempoBottoneUnita) > RitardoFiltraggio) // se il tempo di filtraggio è maggiore del tempo limite allora cambia lo stato
  {
      StatoBottoneUnita = LetturaBottoneUnita;
      if (LetturaBottoneUnita==HIGH)
      {//ho la conferma che è stato premuto il tasto unità
          ValoreUnita++; // incremento il valore
          if (ValoreUnita>9) // se supero il valore 9 ritorno a zero
          {
              ValoreUnita = 0;
          }
          Pressione ("Bottone Unita'");//trasmetto via seriale che è stato premuto il bottone e accendo il led 
     }  
  }
  UltimoStatoBottoneUnita = LetturaBottoneUnita;//memorizza lo stato per confrontarlo al prossimo ciclo


  //lettura dello stato del bottone decine
  //lettura dello stato del bottone decine
  //lettura dello stato del bottone decine
  //lettura dello stato del bottone decine
  int LetturaBottoneDecine = digitalRead(BottoneDecine);  
  if (LetturaBottoneDecine != UltimoStatoBottoneDecine) //se è cambiato
  {
    TempoBottoneDecine = millis();// Memorizzo quando è stato premuto il bottone per la prima volta
  } 
  if ((millis() - TempoBottoneDecine) > RitardoFiltraggio) // se il tempo di filtraggio è maggiore del tempo limite allora cambia lo stato
  {
      StatoBottoneDecine = LetturaBottoneDecine;
      if (LetturaBottoneDecine==HIGH)
      {
          ValoreDecine++;
          if (ValoreDecine>9)
          {
            ValoreDecine = 0;
          }
          Pressione ("Bottone Decine");//trasmetto via seriale che è stato premuto il bottone e accendo il led 
    }  
  }
  UltimoStatoBottoneDecine = LetturaBottoneDecine;//memorizza lo stato per confrontarlo al prossimo ciclo
  
  
  //lettura dello stato di StopDX
  //lettura dello stato di StopDX
  //lettura dello stato di StopDX
  //lettura dello stato di StopDX
  int LetturaStopDX = digitalRead(StopDX);
  if (LetturaStopDX != UltimoStatoStopDX) //se è cambiato
  {
      TempoStopDX = millis();// Memorizzo quando è stato premuto il bottone per la prima volta
  } 
  if ((millis() - TempoStopDX) > RitardoFiltraggio)   // se il tempo di filtraggio è maggiore del tempo limite allora cambia lo stato
  {
      StatoStopDX = LetturaStopDX;
      if (LetturaStopDX==HIGH)
      {
          if (Motore==1) // poichè è intervenuto il fine corsa cambio il senso di rotazione
          {
              SensoRotazioneMotore = 0;       
          }
          Motore = 0 ; // spengo il motore 
          FCSX = 1;    // cambio lo stato del fine corsa DX
          StampaSituazione("Fine corsa SX");
      }  
  }
  UltimoStatoStopDX = LetturaStopDX;//memorizza lo stato per confrontarlo al prossimo ciclo



  //lettura dello stato di StopSX
  //lettura dello stato di StopSX
  //lettura dello stato di StopSX
  //lettura dello stato di StopSX
  int LetturaStopSX = digitalRead(StopSX);
  if (LetturaStopSX != UltimoStatoStopSX)   //se è cambiato
  {
    TempoStopSX = millis();// Memorizzo quando è stato premuto il bottone per la prima volta
  } 
  if ((millis() - TempoStopSX) > RitardoFiltraggio) // se il tempo di filtraggio è maggiore del tempo limite allora cambia lo stato
  {
      StatoStopSX = LetturaStopSX;
      if (LetturaStopSX==HIGH)
      {
          if (Motore==1)// poichè è intervenuto il fine corsa cambio il senso di rotazione
          {
            SensoRotazioneMotore = 1; 
          }
          Motore = 0 ; // spengo il motore 
          FCDX = 1;    // cambio lo stato del fine corsa DX
          StampaSituazione("Fine corsa DX");
       }  
  }
  UltimoStatoStopSX = LetturaStopSX;   //memorizza lo stato per confrontarlo al prossimo ciclo

  
  //Solo quando il motore è fermo viene letto il valore del potenziometro.
  //A ciclo avviato non è possibile cambiare il passo
 if (Motore==0) 
 {
   sensorValue = analogRead(PotPassi);    
   // a seconda di quanto impostato sul potenziometro viene impostato un certo numero di passi 
   //che il motore deve compiere ad ogni scatto
   if ( sensorValue<71) {passo=passo1;LimitePassi=1213;}
   if ( sensorValue>70 && sensorValue<168) {passo=passo2;LimitePassi=606;}
   if ( sensorValue>167 && sensorValue<272){passo=passo3;LimitePassi=404;}
   if ( sensorValue>271 && sensorValue<374){passo=passo4;LimitePassi=303;}
   if ( sensorValue>373 && sensorValue<476){passo=passo5;LimitePassi=242;}
   if ( sensorValue>475 && sensorValue<578){passo=passo6;LimitePassi=202;}
   if ( sensorValue>577 && sensorValue<680){passo=passo7;LimitePassi=151;}
   if ( sensorValue>679 && sensorValue<783){passo=passo8;LimitePassi=101;}
   if ( sensorValue>782 && sensorValue<886){passo=passo9;LimitePassi=75;}
   if ( sensorValue>885 && sensorValue<991){passo=passo10;LimitePassi=37;}
   if ( sensorValue>990 ) {passo=passo11;LimitePassi=18;}
 }
 //calcolo il valore memorizzato
 ValoreMemorizzato = ValoreUnita + ValoreDecine*10 ;
 // moltiplico per 1000 per trasformarlo in secondi
 ValoreMemorizzato = ValoreMemorizzato *1000;
 // Verificando il valore memorizzato vedo se sono in fase automatica o manuale
 // se il valore e' uguale a zero sono in fase manuale.
 //        (cioè premendo i bottoni StopDX e StopSX comando direttamente il motore
 //         il motore funziona fino a quando è premuto il bottone) 
 // se il valore è 11 (undici)sono in fase semiautomatica.
 //        (cioè premendo i bottoni StopDX e StopSX comando direttamente il motore
 //         il motore funziona per un passo e poi si ferma) 
 // se il valore è maggiore di zero ma non è 11 (undici) allora sono in fase automatica
 //        (cioè ogni tot secondi il motore si muove, c'è una piccola attesa per evitare vibrazioni
 //         e poi c'è lo scatto, il motore attende un tot e ripete il ciclo)
  if (ValoreMemorizzato==0) //fase manuale
  {
      if (FCSX==0 && FCDX==1) //se viene premuto il finecorsa dx all'ora faccio girare il motore indietro
      {
          motor.step(PassiMotore, BACKWARD, SINGLE); 
          motor.release();
          StampaSituazione("Avanti");
      }  
      if (FCSX==1 && FCDX==0) //se viene premuto il finecorsa sx all'ora faccio girare il motore avanti
      {
          motor.step(PassiMotore, FORWARD, SINGLE); 
          motor.release();
          StampaSituazione("Indietro");
      }  
  }
  if (ValoreMemorizzato==11000) //fase semiautomatica
  {
      sensorValue = analogRead(PotPassi);    
   // a seconda di quanto impostato sul potenziometro viene impostato un certo numero di passi 
   //che il motore deve compiere ad ogni scatto
      if ( sensorValue<71) {velmotore=10;}
      if ( sensorValue>70 && sensorValue<168) {velmotore=22;}
      if ( sensorValue>167 && sensorValue<272){velmotore=45;}
      if ( sensorValue>271 && sensorValue<374){velmotore=90;}
      if ( sensorValue>373 && sensorValue<476){velmotore=180;}
      if ( sensorValue>475 && sensorValue<578){velmotore=360;}
      if ( sensorValue>577 && sensorValue<680){velmotore=720;}
      if ( sensorValue>679 && sensorValue<783){velmotore=720;}
      if ( sensorValue>782 && sensorValue<886){velmotore=720;}
      if ( sensorValue>885 && sensorValue<991){velmotore=720;}
      if ( sensorValue>990 ) {velmotore=720;}
      if (FCSX==0 && FCDX==1) //se viene premuto il finecorsa dx all'ora faccio girare il motore indietro
      {
           motor.setSpeed(velmotore);
           motor.step(2350, BACKWARD, SINGLE); 
           motor.setSpeed(180);
           motor.release();
           StampaSituazione("Avanti");
      }  
      if (FCSX==1 && FCDX==0) //se viene premuto il finecorsa sx all'ora faccio girare il motore avanti
      {
           motor.setSpeed(velmotore);
           motor.step(2350, FORWARD, SINGLE); 
           motor.setSpeed(180);
           motor.release();
           StampaSituazione("Indietro");
      }  
  }
  if (ValoreMemorizzato>0 && ValoreMemorizzato!=11000)//se ho memorizzato un valore di pausa vuol dire che è un ciclo automatico 
  {
      if (FCSX==1 && FCDX==1) // se sono stati premuti entrambi i fine corsa, vuol dire che si vuole iniziare un nuovo ciclo
      {
          StampaSituazione("Nuovo ciclo"); //iniziamo un nuovo ciclo
          Passi=0;                           // azzero contatore passi
          Motore = 1;                        // accendo il motore
          // faccio una segnalazione tramite il led che sto iniziando un nuovo ciclo
          for (int ciclo=0;ciclo<20;ciclo++)
          {
              digitalWrite(LedPin, HIGH);   // accendo il led
              delay(50);                    // aspetto
              digitalWrite(LedPin, LOW);    // spendo il led
              delay(100);                   // aspetto
          }
     }
     if (Motore==1) // se devo eseguire un nuovo passo
     {
         digitalWrite(LedPin, HIGH);   // accendo il led
         if (SensoRotazioneMotore==0)  // a seconda del senso di rotazione faccio girare il motore in un verso o nell'altro
         {
             interrotto = motor.step(passo*2, BACKWARD, SINGLE); 
         }
         else
         {
             interrotto = motor.step(passo*2, FORWARD, SINGLE); 
         }
         digitalWrite(LedPin, LOW);              // spengo il led
         Passi++;                                // incremento il contatore dei passi
         motor.release();                        // stacco il motore  
         if (interrotto)
         {
             if (interrotto==1)
             {
               SensoRotazioneMotore = 0;       
             }
             if (interrotto==2)
             {
               SensoRotazioneMotore = 1;       
             }
             Motore = 0 ; // spengo il motore 
             StampaSituazione("Emergenza");
         }
         else
         {
           delay(600);                             // aspetto 0,6 sec per "saltare" le vibrazioni dopo il movimento
           digitalWrite(Scatto, HIGH);             // premo il pulsante di scatto
           delay(200);                             // aspetto
           digitalWrite(Scatto, LOW);              // rilascio il pulsante di scatto
           StampaSituazione("Fatto Passo");        // trasmetto via seriale l'avvenuto scatto
           delay(ValoreMemorizzato-800);           // attendo per la pausa impostata (tolgo 800 per le vibrazioni e lo scatto)
         }
     }
/*     
     
     if (FCSX==1 && FCDX==0)// Se interviene il fine corsa fermo il motore
     {
         motor.release();
         SensoRotazioneMotore==0;
     }  
     if (FCSX==0 && FCDX==1)// Se interviene il fine corsa fermo il motore
     {
         motor.release();
         SensoRotazioneMotore==1;
     }  
*/     
     // Verifico quanti passi sono stati effettuati e se ho superato il limite
     if (Passi>LimitePassi-1)
     {        
        Motore = 0 ;                     // spengo il motore     
        motor.release();
        digitalWrite(LedPin, HIGH);     // accendo il led
        delay(2000);                    // attendo
        digitalWrite(LedPin, LOW);      // spengo il led
        if (SensoRotazioneMotore == 0)  // cambio il senso di rotazione per il prossimo ciclo
        {
            SensoRotazioneMotore = 1;   // imposto sinistra   
            StampaSituazione("Superati i limiti del fine corsa DX");
        }  
        else
        {
            SensoRotazioneMotore = 0;   // imposto sinistra   
            StampaSituazione("Superati i limiti del fine corsa SX");
        }  
        Passi=0;                       // azzero il numero dei passi effettuati   
     }
  }
}


